@@ -62,6 +62,4 @@ def get_generic_args(type_):
     if sys.version_info >= (3, 8):
         from typing import get_args
         return get_args(type_)
-    if sys.version_info >= (3, 7):
-        return type_.__args__
-    return type_.__args__
+    return getattr(type_, '__args__', None) or ()
