@@ -2,10 +2,6 @@ from . import pagination
 from .argument_resolver import arguments_resolver
 from .auth import no_authentication
 from .configurer import Configurer
-from .controller import controller
-from .controller import get_component
-from .controller import get_instance
-from .controller import set_factory
 from .exceptions import ExceptionHandler
 from .exceptions import exception_handlers_registry
 from .exceptions import problem
@@ -27,7 +23,6 @@ from .urls import register_url_regexp
 
 
 def setup():
-    from winter.core.json.decoder import JSONDecodeException
     from winter.data.exceptions import NotFoundException
     from .configurer import run_configurers
     from .exceptions import RedirectException
@@ -36,7 +31,6 @@ def setup():
     from .exceptions.problem_handling import ProblemExceptionMapper
     from .exceptions.problem_handling_info import ProblemHandlingInfo
     from .exception_handlers import RedirectExceptionHandler
-    from .exception_handlers import DecodeExceptionHandler
     from .pagination.page_processor_resolver import PageOutputProcessorResolver
     from .pagination.page_position_argument_resolver import PagePositionArgumentResolver
     from .path_parameters_argument_resolver import PathParametersArgumentResolver
@@ -57,7 +51,6 @@ def setup():
     exception_handler_generator = ProblemExceptionHandlerGenerator(exception_mapper)
     autodiscover_problem_annotations(exception_handler_generator)
     auto_handle_exceptions = {
-        JSONDecodeException: DecodeExceptionHandler,
         RedirectException: RedirectExceptionHandler,
         NotFoundException: exception_handler_generator.generate(NotFoundException, ProblemHandlingInfo(status=404)),
     }
