@@ -1,4 +1,5 @@
-import abc
+from abc import ABC
+from abc import abstractmethod
 from typing import Any
 
 from rest_framework.request import Request
@@ -6,7 +7,7 @@ from rest_framework.request import Request
 from .problem_handling_info import ProblemHandlingInfo
 
 
-class ExceptionMapper(abc.ABC):
-    @abc.abstractmethod
+class ExceptionMapper(ABC):
+    @abstractmethod
     def to_response_body(self, request: Request, exception: Exception, handling_info: ProblemHandlingInfo) -> Any:
         pass
