@@ -1,5 +1,6 @@
 from typing import Dict
 
+import dataclasses
 from rest_framework.request import Request as DRFRequest
 
 from winter.data.pagination import Page
@@ -11,6 +12,7 @@ from .utils import get_previous_page_url
 class PageProcessor(IOutputProcessor):
 
     def process_output(self, output: Page, request: DRFRequest) -> Dict:
+        extra_fields = set(dataclasses.fields(output)) - set(dataclasses.fields(Page))
         return {
             'meta': {
                 'total_count': output.total_count,
@@ -18,6 +20,10 @@ class PageProcessor(IOutputProcessor):
                 'offset': output.position.offset,
                 'previous': get_previous_page_url(output, request),
                 'next': get_next_page_url(output, request),
+                **{
+                    extra_field.name: getattr(output, extra_field.name)
+                    for extra_field in extra_fields
+                },
             },
             'objects': output.items,
         }
