@@ -3,6 +3,7 @@ from typing import List
 import dataclasses
 
 from winter.core import annotate_method
+from winter.core.utils.typing import get_origin_type
 
 ListType = type(List)
 
@@ -13,7 +14,8 @@ class RequestBodyAnnotation:
 
 
 def check_request_body_type(argument_type):
-    if not dataclasses.is_dataclass(argument_type) and not isinstance(argument_type, ListType):
+    is_list = issubclass(get_origin_type(argument_type), list)
+    if not dataclasses.is_dataclass(argument_type) and not is_list:
         raise AssertionError('Invalid request body type')
 
 
