@@ -1,5 +1,5 @@
 from .aggregate_root import AggregateRoot
 from .domain_event import DomainEvent
+from .domain_event_dispatcher import global_domain_event_dispatcher
 from .domain_event_handler import domain_event_handler
-from .domain_event_handler import global_domain_event_dispatcher
 from .domain_events import DomainEvents
