@@ -2,15 +2,12 @@ import inspect
 import re
 
 from winter.core.utils.typing import is_union
-from .domain_event_dispatcher import DomainEventDispatcher
+from .domain_event_dispatcher import global_domain_event_dispatcher
 from .domain_event_subscription import DomainEventSubscription
 
 domain_events_class_name_pattern = re.compile(r'typing.List\[.+\]')
 
 
-global_domain_event_dispatcher = DomainEventDispatcher()
-
-
 # noinspection PyPep8Naming
 class domain_event_handler:
     """Decorator for method in class"""
@@ -29,7 +26,7 @@ class domain_event_handler:
         ):
             raise AssertionError('First argument must have annotation and this annotation must be class')
 
-    def __get__(self, instance, owner):
+    def __get__(self, instance, owner):  # pragma: no cover
         return self._method.__get__(instance, owner)
 
     def __set_name__(self, owner, name):
