@@ -4,6 +4,7 @@ import decimal
 import enum
 import inspect
 import types
+import typing
 import uuid
 from collections import OrderedDict
 from collections.abc import Iterable
@@ -15,9 +16,10 @@ from typing import Tuple
 from typing import Type
 
 from drf_yasg import openapi
+from strenum import StrEnum
 
 from winter.core.utils import has_nested_type
-from winter.core.utils.typing import get_origin_type
+from winter.core.utils.typing import get_origin_type, get_generic_args
 from winter.core.utils.typing import is_any
 from winter.core.utils.typing import is_optional
 from winter.core.utils.typing import is_type_var
@@ -57,23 +59,29 @@ class TypeInfo:
     child: Optional['TypeInfo'] = None
     nullable: bool = False
     properties: Dict[str, 'TypeInfo'] = dataclasses.field(default_factory=OrderedDict)
+    properties_defaults: Dict[str, object] = dataclasses.field(default_factory=dict)
     enum: Optional[list] = None
+    title: str = ''
 
     def __eq__(self, other):
         if not isinstance(other, self.__class__):
             return False
         return self.as_dict() == other.as_dict()
 
-    def as_dict(self):
+    def as_dict(self, output: bool = True):
         data = {
             # AnyValue map to Object in OpenApi 2.0
             'type': openapi.TYPE_OBJECT if self.type_ == TYPE_ANY_VALUE else self.type_,
         }
+
+        if self.title:
+            data['title'] = self.title
+
         if self.format_ is not None:
             data['format'] = self.format_
 
         if self.child is not None:
-            data['items'] = self.child.as_dict()
+            data['items'] = self.child.as_dict(output)
 
         if self.nullable:
             data['x-nullable'] = True
@@ -82,12 +90,24 @@ class TypeInfo:
             data['enum'] = self.enum
 
         if self.properties:
-            data['properties'] = {key: value.as_dict() for key, value in self.properties.items()}
+            data['properties'] = {key: value.as_dict(output) for key, value in self.properties.items()}
+
+        if output:
+            required_properties = list(self.properties)
+        else:
+            required_properties = [
+                property_name
+                for property_name in self.properties
+                if property_name not in self.properties_defaults
+            ]
+
+        if required_properties:
+            data['required'] = required_properties
 
         return data
 
-    def get_openapi_schema(self):
-        return openapi.Schema(**self.as_dict())
+    def get_openapi_schema(self, output: bool) -> openapi.Schema:
+        return openapi.Schema(**self.as_dict(output))
 
 
 # noinspection PyUnusedLocal
@@ -134,7 +154,7 @@ def inspect_any(hint_class) -> TypeInfo:
 
 # noinspection PyUnusedLocal
 @register_type_inspector(object, checker=is_type_var)
-def inspect_type_var(hint_class) -> TypeInfo:
+def inspect_type_var(hint_class) -> TypeInfo:  # pragma: no cover
     return TypeInfo(TYPE_ANY_VALUE)
 
 
@@ -167,15 +187,15 @@ def inspect_date(hint_class) -> TypeInfo:
 # noinspection PyUnusedLocal
 @register_type_inspector(list, tuple, set, Iterable)
 def inspect_iterable(hint_class) -> TypeInfo:
-    args = getattr(hint_class, '__args__', None)
-    if args is None:
+    args = get_generic_args(hint_class)
+    if not args:
         return TypeInfo(openapi.TYPE_ARRAY, child=TypeInfo(TYPE_ANY_VALUE))
     child_class = args[0]
     child_type_info = inspect_type(child_class)
     return TypeInfo(openapi.TYPE_ARRAY, child=child_type_info)
 
 
-@register_type_inspector(enum.IntEnum, enum.Enum)
+@register_type_inspector(enum.IntEnum, StrEnum, enum.Enum)
 def inspect_enum(enum_class: Type[enum.Enum]) -> TypeInfo:
     enum_values = [entry.value for entry in enum_class]
     # Try to infer type based on enum values
@@ -205,7 +225,14 @@ def inspect_dataclass(hint_class) -> TypeInfo:
         field.name: inspect_type(field.type)
         for field in fields
     }
-    return TypeInfo(type_=openapi.TYPE_OBJECT, properties=properties)
+    defaults = {
+        field.name: field.default
+        for field in fields
+        if field.default != dataclasses.MISSING
+    }
+    cls = hint_class if isinstance(hint_class, type) else type(hint_class)
+    title = cls.__name__
+    return TypeInfo(type_=openapi.TYPE_OBJECT, properties=properties, properties_defaults=defaults, title=title)
 
 
 @register_type_inspector(object, checker=has_nested_type)
@@ -223,6 +250,14 @@ def inspect_new_type(hint_class) -> TypeInfo:
     return inspect_type(hint_class.__supertype__)
 
 
+@register_type_inspector(
+    typing.NewType,
+    checker=lambda instance: getattr(instance, '__supertype__', None) is not None,
+)
+def inspect_new_type_class(hint_class) -> TypeInfo:
+    return inspect_type(hint_class.__supertype__)
+
+
 def inspect_type(hint_class) -> TypeInfo:
     origin_type = get_origin_type(hint_class)
 
