@@ -14,6 +14,7 @@ from sqlalchemy.orm import class_mapper
 from sqlalchemy.orm import sessionmaker
 from sqlalchemy.orm.exc import UnmappedClassError
 
+from winter.core import get_injector
 from winter.data import CRUDRepository
 from winter.data.exceptions import NotFoundException
 from winter_ddd import AggregateRoot
@@ -35,7 +36,7 @@ def sqla_crud(repository_cls):
 
     try:
         mapper = class_mapper(entity_cls)
-    except UnmappedClassError:
+    except UnmappedClassError:  # pragma: no cover
         raise TypeError('Invalid SQLAlchemy entity class given')
 
     if len(mapper.tables) > 1:
@@ -43,7 +44,7 @@ def sqla_crud(repository_cls):
 
     entity_table = mapper.tables[0]
 
-    class RepositoryImpl(repository_cls):
+    class DefaultCRUDRepositoryImpl:
         """
         SQLAlchemy implementation for CRUDRepository
         This repository implementation is not thread-safe.
@@ -52,52 +53,52 @@ def sqla_crud(repository_cls):
             pass
 
         def count(self) -> int:
-            return self._engine.execute(select([func.count()]).select_from(entity_table)).scalar()
+            return self.__engine.execute(select([func.count()]).select_from(entity_table)).scalar()
 
         def delete(self, entity: T):
             try:
-                session = self._sessions[entity]
-            except KeyError:
+                session = self.__sessions[entity]
+            except KeyError:  # pragma: no cover
                 raise self.RepositoryException('Entity must be fetched with repository before being deleted')
             pk = inspect(entity).identity
-            del self._identity_map[pk]
+            del self.__identity_map[pk]
             session.delete(entity)
             session.commit()
             session.close()
-            del self._sessions[entity]
+            del self.__sessions[entity]
 
         def delete_many(self, entities: Iterable[T]):
             for entity in entities:
                 self.delete(entity)
 
-        def delete_all(self):
-            self._engine.execute(entity_table.delete())
-            self._identity_map = {}
-            for session in self._sessions.values():
+        def delete_all(self):  # pragma: no cover
+            self.__engine.execute(entity_table.delete())
+            self.__identity_map = {}
+            for session in self.__sessions.values():
                 session.close()
-            self._sessions = {}
+            self.__sessions = {}
 
-        def delete_by_id(self, id_: K):
+        def delete_by_id(self, id_: K):  # pragma: no cover
             if not isinstance(id_, tuple):
                 id_ = (id_,)
-            if id_ in self._identity_map:
-                entity = self._identity_map[id_]
+            if id_ in self.__identity_map:  # pragma: no cover
+                entity = self.__identity_map[id_]
                 self.delete(entity)
             else:
                 expressions = (column == value for column, value in zip(entity_table.primary_key.columns, id_))
-                self._engine.execute(entity_table.delete().where(and_(*expressions)))
+                self.__engine.execute(entity_table.delete().where(and_(*expressions)))
 
-        def exists_by_id(self, id_: K) -> bool:
+        def exists_by_id(self, id_: K) -> bool:  # pragma: no cover
             if not isinstance(id_, tuple):
                 id_ = (id_,)
-            if id_ in self._identity_map:
+            if id_ in self.__identity_map:
                 return True
             expressions = (column == value for column, value in zip(entity_table.primary_key.columns, id_))
-            return self._engine.execute(select([exists().where(and_(*expressions))])).scalar()
+            return self.__engine.execute(select([exists().where(and_(*expressions))])).scalar()
 
         def find_all(self) -> Iterable[T]:
-            ids = self._engine.execute(select(entity_table.primary_key.columns))
-            ids = next(zip(*ids))
+            ids = self.__engine.execute(select(entity_table.primary_key.columns))
+            ids = next(zip(*ids), [])
             return self.find_all_by_id(ids)
 
         def find_all_by_id(self, ids: Iterable[K]) -> Iterable[T]:
@@ -105,22 +106,22 @@ def sqla_crud(repository_cls):
             result = [entity for entity in result if entity]
             return result
 
-        def find_by_id(self, id_: K) -> Optional[T]:
+        def find_by_id(self, id_: K) -> Optional[T]:  # pragma: no cover
             if not isinstance(id_, tuple):
                 id_ = (id_,)
-            if id_ in self._identity_map:
-                return self._identity_map[id_]
+            if id_ in self.__identity_map:
+                return self.__identity_map[id_]
 
-            session = self._session_factory()
+            session = self.__session_factory()
             instance = session.query(entity_cls).get(id_)
             if instance is None:
                 return None
 
-            self._identity_map[id_] = instance
-            self._sessions[instance] = session
+            self.__identity_map[id_] = instance
+            self.__sessions[instance] = session
             return instance
 
-        def get_by_id(self, id_: K) -> T:
+        def get_by_id(self, id_: K) -> T:  # pragma: no cover
             entity = self.find_by_id(id_)
             if entity is None:
                 raise NotFoundException(id_, entity_cls)
@@ -139,12 +140,12 @@ def sqla_crud(repository_cls):
             return entities
 
         def _save(self, entity: T):
-            if entity not in self._sessions:
-                self._sessions[entity] = self._session_factory()
-                self._sessions[entity].add(entity)
-            self._sessions[entity].flush()
+            if entity not in self.__sessions:
+                self.__sessions[entity] = self.__session_factory()
+                self.__sessions[entity].add(entity)
+            self.__sessions[entity].flush()
             pk = inspect(entity).identity
-            self._identity_map[pk] = entity
+            self.__identity_map[pk] = entity
 
         def _process_domain_events(self, aggregates: Iterable[AggregateRoot]):
             domain_events: List[DomainEvent] = []
@@ -155,17 +156,19 @@ def sqla_crud(repository_cls):
 
         @inject
         def __init__(self, engine: Engine):
-            self._engine = engine
-            self._session_factory = sessionmaker(bind=self._engine)
-            self._identity_map = {}
-            self._sessions = {}
+            self.__engine = engine
+            self.__session_factory = sessionmaker(bind=self.__engine)
+            self.__identity_map = {}
+            self.__sessions = {}
 
-    # def func1(self, name, lastname):
-    #     return self._session_factory().query(entity_cls).filter(
-    #         getattr(entity_cls, 'name') == name,
-    #         getattr(entity_cls, 'lastname') == lastname,
-    #     ).one_or_none()
-    #
-    # RepositoryImpl.find_one_by_name_and_lastname = func1
+    repository_subclasses = repository_cls.__subclasses__()
+
+    class RepositoryImpl(DefaultCRUDRepositoryImpl, *repository_subclasses):
+        @inject
+        def __init__(self):
+            injector = get_injector()
+            injector.call_with_injection(DefaultCRUDRepositoryImpl.__init__, self)
+            for subclass in repository_subclasses:
+                injector.call_with_injection(subclass.__init__, self)
 
     return RepositoryImpl
